@@ -1,5 +1,5 @@
 /* client.c --- DIGEST-MD5 mechanism from RFC 2831, client side.
- * Copyright (C) 2002, 2003, 2004, 2006  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004, 2006, 2008  Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -20,7 +20,7 @@
  *
  */
 
-#if HAVE_CONFIG_H
+#ifdef HAVE_CONFIG_H
 # include "config.h"
 #endif
 
@@ -34,6 +34,7 @@
 #include <string.h>
 
 /* Get tools. */
+#include "nonascii.h"
 #include "tokens.h"
 #include "parser.h"
 #include "printer.h"
@@ -183,9 +184,13 @@ _gsasl_digest_md5_client_step (Gsasl_session * sctx,
 	  if (!c)
 	    return GSASL_NO_PASSWORD;
 
-	  if (asprintf (&tmp, "%s:%s:%s", state->response.username,
-			state->response.realm ?
-			state->response.realm : "", c) < 0)
+	  tmp2 = utf8tolatin1ifpossible (c);
+
+	  rc = asprintf (&tmp, "%s:%s:%s", state->response.username,
+			 state->response.realm ?
+			 state->response.realm : "", tmp2);
+	  free (tmp2);
+	  if (rc < 0)
 	    return GSASL_MALLOC_ERROR;
 
 	  rc = gsasl_md5 (tmp, strlen (tmp), &tmp2);
