@@ -1,5 +1,5 @@
 /* internal.h --- Internal header with hidden library handle structures.
- * Copyright (C) 2002, 2003, 2004, 2005, 2006  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004, 2005, 2006, 2008  Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -23,7 +23,7 @@
 #ifndef INTERNAL_H
 # define INTERNAL_H
 
-# if HAVE_CONFIG_H
+# ifdef HAVE_CONFIG_H
 #  include "config.h"
 # endif
 
@@ -82,7 +82,9 @@ struct Gsasl_session
   Gsasl_mechanism *mech;
   void *mech_data;
   void *application_hook;
-  /* Properties. */
+
+  /* Properties.  If you add anything here, remember to change change
+     gsasl_finish().  */
   char *anonymous_token;
   char *authid;
   char *authzid;
@@ -94,6 +96,8 @@ struct Gsasl_session
   char *hostname;
   char *gssapi_display_name;
   char *realm;
+  char *digest_md5_hashed_password;
+
 #ifndef GSASL_NO_OBSOLETE
   /* Obsolete stuff. */
   void *application_data;
